@@ -1,4 +1,4 @@
-from django.conf.urls import include, patterns, url
+from django.conf.urls import include, url
 
 from rest_framework.routers import SimpleRouter
 
@@ -8,6 +8,6 @@ from .. import views
 router = SimpleRouter(trailing_slash=False)
 router.register(r'pages', views.PageViewSet)
 
-urlpatterns = patterns('',
+urlpatterns = [
     url(r'', include(router.urls)),
-)
+]
